@@ -5,6 +5,7 @@ use strict;
 use warnings;
 
 use Moose;
+use MooseX::StrictConstructor;
 use Carp;
 use Try::Tiny;
 use namespace::autoclean;
@@ -16,11 +17,11 @@ Date::Lectionary::Year - Cycle Year for the Lectionary
 
 =head1 VERSION
 
-Version 1.20161227
+Version 1.20180108
 
 =cut
 
-our $VERSION = '1.20161227';
+our $VERSION = '1.20180108';
 
 =head1 SYNOPSIS
 
@@ -80,13 +81,11 @@ sub _determineYear {
             return 'C';
         }
         else {
-            confess "The liturgical year for the year [" . $calYear
-              . "] could not be determined.";
+            confess "The liturgical year for the year [" . $calYear . "] could not be determined.";
         }
     }
     catch {
-        confess "A liturgical year for the value [" . $calYear
-          . "] could not be calculated.";
+        confess "A liturgical year for the value [" . $calYear . "] could not be calculated.";
     };
 }
 
@@ -135,13 +134,15 @@ Many thanks to my beautiful wife, Jennifer, and my amazing daughter, Rosemary.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Michael Wayne Arnold.
+Copyright 2016-2017 MICHAEL WAYNE ARNOLD
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
+Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
-See L<http://dev.perl.org/licenses/> for more information.
+1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
+
+2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
+
+THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 =cut
